RUNDEF Section05

/*
PROMOTING THE VALUE OF A SELECTED INDIVIDUAL 
SAVING PERMANENTLY A VARIABLE IN THE DATABASE

Program description:
This program selects the age of the household head and saves
it as a household variable. This operation is valid since only
one person will qualify (the head of household is unique).
The program illustrates the way a person variable may be promoted
to the household level. 

A simple frequency can be used to check households having heads
of an age lesser than the acceptable limit. 
*/

DEFINE HOUSIN.AGEHEAD AS PERSON.AGE
  FOR PERSON.RELAT = 1
  VARLABEL "Age of Head of Household"
  RANGE 0 - 100
  SAVE "Housin_AGEHEAD.rbf" OVERWRITE
  
TABLE VERIF AS FREQUENCY OF HOUSIN.AGEHEAD
  FOR HOUSIN.AGEHEAD <= 15

/*
Programming notes:
1. The DEFINE command includes the SAVE clause that triggers the
   permanent addition of the variable to the database. The file
   name containing the data must include the full path, otherwise
   it will be saved in the working directory defined in the database
   dictionary or in Preferences. The example assumes the Redatam
   installation default.
2. Only the low ages (<=15) are tabulated. The clause FOR HOUSIN.AGEHEAD <= 15
   restricts the tabulation for those head of household lesser than
   or equal to 15 years of age.
3. The RANGE clause must be specified. A variable cannot be saved
   without this clause. When the range of the variable to be saved
   is not known a priori, a dry run (without the SAVE clause) can
   be performed with a non-restricted tabulation (no FOR clause)
   in order to establish the range of the variable.
4. There can be no SELECTION file when a variable is saved in the
   database, that is, SELECTION ALL must be selected (which is the
   default).
5. No filters can be applied in the RUNDEF command when saving a
   variable.
6. The VARLABEL clause specify the label for the new variable.
7. The OVERWRITE parameter in the SAVE clause allows the output
   file (Housin_AGEHEAD.rbf) to be rewritten.
 
Results:
    Categories  Counts
    15          171
    Total       171

Comments:
1. After executing the program, the updated dictionary shows a new
   variable (AGEHEAD) in the HOUSIN entity.
   The dictionary must be saved in order for this change to be permanent.
2. When, for any reason, the variable must be recreated, the variable
   name should be deleted from the dictionary prior to executing the
   program. Remember that there are two different things, the variable
   name in the dictionary (which must be deleted), and the file 
   storing the variable data, which can be rewritten automatically
   using the OVERWRITE clause.
3. It is good programming practice to name the file using the entityname
   and the vgariable name, separated by an underscore. The file extension
   is unecessary, although it tells us that this is a Redatam Binary
   File (rbf).
4. It is useful to run an Easy frequency for the variable that has been created.
   By doing this you will see that there are 2544 households with a
   Not applicable value for the AGEHEAD. They correspond to the households
   having no person being the household head (see Section01).
   If you wanted to, you could have used the DEFAULT 0 (or any other
   value) clause in the DEFINE command, to establish the value for the
   cases that do not apply.
*/