RUNDEF Section08

/*
DERIVING A BINARY VARIABLE USING A LOGICAL EXPRESSION

Program description:
The program derives a binary variable (a variable with only two possible values).
The values are assimilated to true or false, yes or no etc 
The syntax of REDATAM is a logical expression within or in place of an arithmetic
expression, being evaluated to 0 (if false) or to 1 (if true).
For example, the expression (PERSON.AGE < 15) will be evaluated to INTEGER 1
if the expression is true and to INTEGER 0 if it is false.
This feature is very useful for evaluating a set of conditions based on the
values of an original variable.
It is a special case of RECODING when the new variable only has two categories.

The following example derives a binary variable from the water origin of the household.
If the origin is "public network" the variable value will be 1, otherwise 0. 
*/

DEFINE HOUSIN.PUBL AS HOUSIN.WATERO = 1
   VARLABEL "Water availability by Public network"
   TYPE BOOL
   
TABLE VERIF1 AS FREQUENCY OF HOUSIN.PUBL
TABLE VERIF2 AS FREQUENCY OF HOUSIN.WATERO BY HOUSIN.PUBL


/*
Programming notes:
1. By defining the new variable as type BOOL, the system automatically establishes
   the range of 0-1 and the valuelabels of False and True.
2. The second table is presented to show how the categories of the original variable
   are transformed to the new one. Only the line "public network" becomes "true".

Results:
Table VERIF1 - Simple frequency
    Categories   Counts      %
    False          6354   45,6
    True           7565   54,4
    Total         13919  100,0

TABLE VERIF2 - Crosstabs
Water Origin   Water availability by Public network		
                   False   True   Total
 No response        2544      -    2544
 Public network        -   7565    7565
 Well or noria      2124      -    2124
 River creek        1467      -    1467
 Other               219      -     219
 Total              6354   7565   13919

Comments:
1. According to the first table, 54,4% of the households are connected to the
   public network, but this result is misleading, since, as you can see in the
   second table, there are 2544 cases that do not respond to this question (collective households,
   unnocupied households, and others).
   So, to be exact, they should be filtered from the define, as
   DEFINE HOUSIN.PUBL1 AS HOUSIN.WATERO = 1
   ...
   FOR HOUSIN.WATERO <> 0
2. By doing that the percentage of serviced households would increase to 66,5%.
*/
