RUNDEF Section20
   FOR HOUSIN.SEXHEAD = 1 OR HOUSIN.SEXHEAD = 2
   
/*
CALCULATING AN INDEX ON BUILDING CONDITIONS

Program description:
This program establishes a score for each living accommodation.
The score is defined as the arithmetic sum of 6 binary variables
that characterize the physical conditions of the building:
water origin, cooking fuel, toilet connection
and types of walls, floor and roof. 

The choice of the variables is arbitrary and may be adapted to more
realistic conditions.
Each binary variable reflects a good condition at value 1.
*/

//Accepts only public network
DEFINE HOUSIN.BIN1
  AS HOUSIN.WATERO = 1
  TYPE BOOL
  DEFAULT 0

//Acepts Gas or electricity
DEFINE HOUSIN.BIN2
  AS HOUSIN.FUEL = 1 OR HOUSIN.FUEL = 4
  TYPE BOOL
  DEFAULT 0

//Accepts only sewage system
DEFINE HOUSIN.BIN3
  AS HOUSIN.TOILCO = 1
  TYPE BOOL
  DEFAULT 0

//Accepts concrete or clay brick
DEFINE HOUSIN.BIN4
  AS HOUSIN.WALLS = 1 OR HOUSIN.WALLS = 3
  TYPE BOOL
  DEFAULT 0

//Accepts Slate or tiles
DEFINE HOUSIN.BIN5
  AS HOUSIN.ROOF = 2 OR HOUSIN.ROOF = 3
  TYPE BOOL
  DEFAULT 0

//Accepts parquet or carpeting
DEFINE HOUSIN.BIN6
  AS HOUSIN.FLOOR = 1 OR HOUSIN.FLOOR = 3
  TYPE BOOL
  DEFAULT 0
  
DEFINE HOUSIN.CONDITION
  AS HOUSIN.BIN1 + HOUSIN.BIN2 + HOUSIN.BIN3 + HOUSIN.BIN4 + HOUSIN.BIN5 + HOUSIN.BIN6
  RANGE 0-6
  TYPE INTEGER
  VARLABEL "Dwelling Conditions"
  VALUELABELS 0 "Very bad"  1 "Bad"  2 "Medium bad"
              3 "Medium good" 4 "Good" 5 "Very Good" 
              6 "Excellent"
              
TABLE VERIF AS FREQUENCY OF HOUSIN.CONDITION

/*
Programming notes:
1. As this type of indicator applies only to private and occupied households,
   we decided to filter the cases using the SEXHEAD (sex of the household).
   If we look at the frequency of this variable and the frequency of the
   ones being used for the indicators, we will see that all of them has the
   "magic" 2544 number for the non response, so, it is fairly safe to use the
   SEXHEAD as our filter in the RUNDEF command.
2. The specific filters for each binary indicator is commented in place.
3. The range of the CONDITION variable varies from 0-6. The quality index
   has 7 values. 
4. All DEFINEs that create the binary indicators include the DEFAULT 0 clause,
   so that any non-applicable or missing value does not invalidate the variable
   and thus the final sum. Any missing or non-applicable are evaluated as 0.
   
Results:
Categories      Counts      %
 Very bad          704   6,19
 Bad              1833  16,11
 Medium bad       3069  26,98
 Medium good      2782  24,46
 Good             2182  19,18
 Very Good         752   6,61
 Excellent          53   0,47
 Total           11375 100,00

Comments:
1. The majority of dwellings are considered in medium bad or medium good conditions,
   according to the specific choice of options.
2. This score may be saved permanently in the base in order to produce an area list.    
*/
